@@ -128,7 +128,8 @@ class AlertMsg(NotificationMsg):
                  key: Union[str, List[str]],
                  desc: str,
                  ttl: Optional[int] = None,
-                 priority: Optional[Priority] = None):
+                 priority: Optional[Priority] = None,
+                 from_msg: Optional[Message] = None):
         if priority is not None and priority < Priority.WARNING:
             raise ValueError('Alerts can only have a priority of WARNING (2) or higher')
         if not desc:
@@ -138,6 +139,7 @@ class AlertMsg(NotificationMsg):
         super().__init__(desc=desc, priority=priority or Priority.WARNING,
                          ttl=ttl or 30, contents=contents)
         self.alert_key: str = '['+']['.join(key)+']' if isinstance(key, List) else key
+        self.msg = from_msg
 
     def compare(self, other: 'AlertMsg') -> AlertComparison:
         return AlertComparison(self, other)
@@ -172,7 +174,7 @@ class AlertMsg(NotificationMsg):
                              f'as it does not have a description: {pformat(msg.to_dict())}')
         return AlertMsg(msg.contents, key=msg.contents['alert_key'],
                         desc=msg.contents['description'], ttl=msg.contents['ttl'],
-                        priority=priority_of(msg.contents['priority']))
+                        priority=priority_of(msg.contents['priority']), from_msg=msg)
 
 
 class WarningMsg(AlertMsg):
